@@ -1,7 +1,4 @@
 from graphgallery.data.dataset import Dataset
 from graphgallery.data.planetoid import Planetoid
 from graphgallery.data.npz_dataset import NPZDataset
-from graphgallery.data.io import SparseGraph
-
-
-
+from graphgallery.data.graph import Graph, Basegraph
