@@ -4,20 +4,23 @@ import os.path as osp
 import numpy as np
 
 from graphgallery.data import Dataset
-from graphgallery.data.io import makedirs, files_exist, download_file, SparseGraph, load_dataset
+from graphgallery.data.io import makedirs, files_exist, download_file
+from graphgallery.data.graph import Graph, load_dataset
+
+
+_DATASETS = ('citeseer', 'cora', 'cora_ml', 'cora_full', 'amazon_cs', 'amazon_photo',
+             'coauthor_cs', 'coauthor_phy', 'polblogs', 'pubmed', 'flickr', 'flickr_sdm', 'blogcatalog')
 
 
 class NPZDataset(Dataset):
 
     github_url = "https://raw.githubusercontent.com/EdisonLeeeee/GraphData/master/datasets/npz/{}.npz"
-    supported_datasets = ('citeseer', 'cora', 'cora_ml', 'cora_full', 'amazon_cs', 'amazon_photo',
-                          'coauthor_cs', 'coauthor_phy', 'polblogs', 'pubmed', 'reddit')
+    supported_datasets = _DATASETS
 
     def __init__(self, name, root=None, url=None, standardize=False, verbose=True):
-        name = name.lower()
 
-        if not name in self.supported_datasets:
-            raise ValueError(f"Currently only support for these datasets {self.supported_datasets}.")
+        if not name.lower() in self.supported_datasets:
+            print(f"Dataset not Found. Using custom dataset: {name}.\n")
 
         super().__init__(name, root, verbose)
 
@@ -49,10 +52,11 @@ class NPZDataset(Dataset):
     def process(self):
 
         print("Processing...")
-        dataset_graph = load_dataset(self.raw_paths[0]).eliminate_self_loops().to_undirected().to_dense_attrs()
+        graph = load_dataset(
+            self.raw_paths[0]).eliminate_selfloops().to_undirected()
         if self.standardize:
-            dataset_graph.standardize()
-        self.graph = dataset_graph
+            graph = graph.standardize()
+        self.graph = graph
         print("Processing completed.")
 
     @property
