@@ -5,8 +5,12 @@ import pickle as pkl
 
 
 from graphgallery.data import Dataset
-from graphgallery.data.io import makedirs, files_exist, download_file, SparseGraph
+from graphgallery.data.io import makedirs, files_exist, download_file
 from graphgallery.data.preprocess import process_planetoid_datasets
+from graphgallery.data.graph import Graph
+
+
+_DATASETS = {'citeseer', 'cora', 'pubmed'}
 
 
 class Planetoid(Dataset):
@@ -20,13 +24,14 @@ class Planetoid(Dataset):
     """
 
     github_url = "https://raw.githubusercontent.com/EdisonLeeeee/GraphData/master/datasets/planetoid"
-    supported_datasets = {'citeseer', 'cora', 'pubmed'}
+    supported_datasets = _DATASETS
 
     def __init__(self, name, root=None, verbose=True):
         name = name.lower()
 
         if not name in self.supported_datasets:
-            raise ValueError(f"Currently only support for these datasets {self.supported_datasets}.")
+            raise ValueError(
+                f"Currently only support for these datasets {self.supported_datasets}.")
 
         super().__init__(name, root, verbose)
 
@@ -54,8 +59,9 @@ class Planetoid(Dataset):
     def process(self):
 
         print("Processing...")
-        adj, attributes, labels, idx_train, idx_val, idx_test = process_planetoid_datasets(self.name, self.raw_paths)
-        self.graph = SparseGraph(adj, attributes, labels).eliminate_self_loops().to_undirected().to_dense_attrs()
+        adj, attributes, labels, idx_train, idx_val, idx_test = process_planetoid_datasets(
+            self.name, self.raw_paths)
+        self.graph = Graph(adj, attributes, labels).eliminate_selfloops()
         self.idx_train = idx_train
         self.idx_val = idx_val
         self.idx_test = idx_test
