@@ -12,43 +12,51 @@ class Deepwalk(UnsupervisedModel):
         Implementation of DeepWalk Unsupervised Graph Neural Networks (DeepWalk). 
         `DeepWalk: Online Learning of Social Representations <https://arxiv.org/abs/1403.6652>`
         Implementation: <https://github.com/phanein/deepwalk>
+    """
+    def __init__(self, *graph, device='cpu:0', seed=None, name=None, **kwargs):
+        """Creat an unsupervised Deepwalk model.
 
+        This can be instantiated in several ways:
+
+            model = Deepwalk(graph)
+                with a `graphgallery.data.Graph` instance representing
+                A sparse, attributed, labeled graph.
+
+            model = Deepwalk(adj_matrix, attr_matrix, labels)
+                where `adj_matrix` is a 2D Scipy sparse matrix denoting the graph,
+                 `attr_matrix` is a 2D Numpy array-like matrix denoting the node 
+                 attributes, `labels` is a 1D Numpy array denoting the node labels.
+                 
+            model = Deepwalk(adj_matrix, None, labels)
+                where `adj_matrix` is a 2D Scipy sparse matrix denoting the graph,
+                `labels` is a 1D Numpy array denoting the node labels.           
+                Note that the `attr_matirx` is not necessary.
+                 
         Parameters:
         ----------
-            adj: Scipy.sparse.csr_matrix, shape [n_nodes, n_nodes]
-                The input `symmetric` adjacency matrix in CSR format.
-            labels: Numpy.ndarray, shape [n_nodes]
-                Array, where each entry represents respective node's label(s).
-            device: string. optional 
-                The device where the model is running on. You can specified `CPU` or `GPU` 
-                for the model. (default: :str: `CPU:0`, i.e., running on the 0-th `CPU`)
-            seed: interger scalar. optional 
-                Used in combination with `tf.random.set_seed` & `np.random.seed` 
-                & `random.seed` to create a reproducible sequence of tensors across 
-                multiple calls. (default :obj: `None`, i.e., using random seed)
-            name: string. optional
-                Specified name for the model. (default: :str: `class.__name__`)
-
-    """
-
-    def __init__(self, adj, labels, device='CPU:0', seed=None, name=None, **kwargs):
-
-        super().__init__(adj, labels=labels, device=device, seed=seed, name=name, **kwargs)
+        graph: An instance of `graphgallery.data.Graph` or a tuple (list) of inputs.
+            A sparse, labeled graph.
+        device: string. optional 
+            The device where the model is running on. You can specified `CPU` or `GPU` 
+            for the model. (default: :str: `CPU:0`, i.e., running on the 0-th `CPU`)
+        seed: interger scalar. optional 
+            Used in combination with `tf.random.set_seed` & `np.random.seed` 
+            & `random.seed` to create a reproducible sequence of tensors across 
+            multiple calls. (default :obj: `None`, i.e., using random seed)
+        name: string. optional
+            Specified name for the model. (default: :str: `class.__name__`)        
+            
+        """
+        super().__init__(*graph, device=device, seed=seed, name=name, **kwargs)
 
     def build(self, walk_length=80, walks_per_node=10,
               embedding_dim=64, window_size=5, workers=16,
               iter=1, num_neg_samples=1):
 
-        ############# Record paras ###########
-        local_paras = locals()
-        local_paras.pop('self')
-        paras = Bunch(**local_paras)
-        # update all parameters
-        self.paras.update(paras)
-        self.model_paras.update(paras)
 
-        walks = self.deepwalk_random_walk(self.adj.indices,
-                                          self.adj.indptr,
+        adj_matrix = self.graph.adj_matrix
+        walks = self.deepwalk_random_walk(adj_matrix.indices,
+                                          adj_matrix.indptr,
                                           walk_length=walk_length,
                                           walks_per_node=walks_per_node)
 
