@@ -2,39 +2,39 @@
 import numpy as np
 import tensorflow as tf
 
-from graphgallery import astensors, sample_mask
-from graphgallery.sequence.node_sequence import NodeSequence
+from graphgallery import transformers as T
+from graphgallery.sequence.base_sequence import Sequence
 
 
-class NodeSampleSequence(NodeSequence):
+class SBVATSampleSequence(Sequence):
 
     def __init__(
         self,
-        inputs,
-        labels,
+        x,
+        y,
         neighbors,
-        n_samples=100,
-        resample=True
+        n_samples=50,
+        resample=True,
+        *args, **kwargs
     ):
-
-        self.inputs = inputs
-        self.labels = labels
-        self.n_batches = 1
+        super().__init__(*args, **kwargs)
+        self.x = x
+        self.y = y
         self.neighbors = neighbors
-        self.n_nodes = inputs[0].shape[0]
+        self.n_nodes = x[0].shape[0]
         self.n_samples = n_samples
         self.adv_mask = self.smple_nodes()
         self.resample = resample
 
     def __len__(self):
-        return self.n_batches
+        return 1
 
     def __getitem__(self, index):
+        return T.astensors(*self.x, self.adv_mask), T.astensor(self.y)
 
-        item = [*self.inputs, self.adv_mask], self.labels
+    def on_epoch_end(self):
         if self.resample:
             self.adv_mask = self.smple_nodes()
-        return astensors(item)
 
     def smple_nodes(self):
         N = self.n_nodes
